// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
import * as vscode from 'vscode';
import CompletionItemProvider from './completionItemProvider';
import Commands from './commands';

// this method is called when your extension is activated
// your extension is activated the very first time the command is executed
export function activate(context: vscode.ExtensionContext) {
	// Register Build Commands
	// The Command was defined in package.json and the commandId parameter has
	// to be equal to the 'command' field in the package.json file
	context.subscriptions.push(vscode.commands.registerTextEditorCommand(
		'latex.pdflatex',
		Commands.latex_pdflatex,
		{ extensionPath: context.extensionPath }
	));
	context.subscriptions.push(vscode.commands.registerTextEditorCommand(
		'latex.makeindex',
		Commands.latex_makeindex,
		{ extensionPath: context.extensionPath }
	));
	
	// Register the Completion Item Provider
	context.subscriptions.push(vscode.languages.registerCompletionItemProvider(
		[{ language: 'latex' }],        // document selector
		new CompletionItemProvider(),   // A Complete Item Provider instance
		'\\', '{', '[' //, '='          // Characters to trigger an completion suggestion
	));
}
